NovvyAdInternalEvent class

Internal wrapper for a native ad event.

Constructors

NovvyAdInternalEvent({required String adObjectId, required String adUnitId, required NovvyAdEvent event, String? error, Map<String?, Object?>? data})

Properties

adObjectId String
final
adUnitId String
final
data Map<String?, Object?>?
final
error String?
final
event NovvyAdEvent
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited